@@ -26,6 +26,19 @@ rlang::`:=`
 ## See: \url{https://github.com/tidyverse/magrittr/issues/29}
 utils::globalVariables(c("."))
 
+## Suppress R CMD check note 'All declared Imports should be used'.
+## These packages are used by caret to train models and evaluate performance.
+## The datasets cannot be loaded if these packages aren't declared in Imports.
+## See https://community.rstudio.com/t/how-should-a-meta-package-handle-this-note-all-declared-imports-should-be-used/23400/3
+#' @importFrom MLmetrics AUC
+#' @importFrom e1071 best.randomForest
+#' @importFrom glmnet glmnet
+#' @importFrom kernlab as.kernelMatrix
+#' @importFrom randomForest getTree
+#' @importFrom rpart rpart
+#' @importFrom xgboost xgboost
+NULL
+
 #' Randomize feature order to eliminate any position-dependent effects
 #'
 #'
